JISC Answers

Log | Undo | Ownership | Interfaces | Security

Site Error Log at /error_log

This page lists the exceptions that have occurred in this site recently. You can configure how many exceptions should be kept and whether the exceptions should be copied to Zope's event log file(s).

Number of exceptions to keep |
Copy exceptions to the event log |
Ignored exception types |

### Exception Log (most recent first)

Time | Username (User Id) | Exception |
--- | --- | --- | ---
09:40:39 | Anonymous User (None) | Unauthorized: You are not allowed to access '@@make_subsite' in this context |
09:39:16 | Anonymous User (None) | Unauthorized: <AccessControl.unauthorized.Unauthorized instance at 0x80f84c200> |